@@ -58,7 +58,7 @@ func New(dir string, options ...Option) (app *App, err error) {
 	if o.Conn != nil {
 		listener, err := net.Listen("unix", o.UnixSocket)
 		if err != nil {
-			return nil, fmt.Errorf("Failed to autobind unix socket: %w", err)
+			return nil, fmt.Errorf("failed to autobind unix socket: %w", err)
 		}
 
 		nodeBindAddress = listener.Addr().String()
@@ -220,11 +220,6 @@ func New(dir string, options ...Option) (app *App, err error) {
 		return nil, fmt.Errorf("invalid voters %d: must be an odd number greater than 1", o.Voters)
 	}
 
-	if o.StandBys%2 == 0 {
-		stop()
-		return nil, fmt.Errorf("invalid stand-bys %d: must be an odd number", o.StandBys)
-	}
-
 	if runtime.GOOS != "linux" && nodeBindAddress[0] == '@' {
 		// Do not use abstract socket on other platforms and left trim "@"
 		nodeBindAddress = nodeBindAddress[1:]
@@ -281,13 +276,13 @@ func New(dir string, options ...Option) (app *App, err error) {
 				n, err := remote.Write(data)
 				if err != nil || n != len(data) {
 					remote.Close()
-					panic(fmt.Errorf("Failed to write connection header: %w", err))
+					panic(fmt.Errorf("failed to write connection header: %w", err))
 				}
 
 				local, err := net.Dial("unix", nodeBindAddress)
 				if err != nil {
 					remote.Close()
-					panic(fmt.Errorf("Failed to connect to bind address %q: %w", nodeBindAddress, err))
+					panic(fmt.Errorf("failed to connect to bind address %q: %w", nodeBindAddress, err))
 				}
 
 				go proxy(app.ctx, remote, local, nil)
@@ -372,6 +367,7 @@ func (a *App) Handover(ctx context.Context) error {
 				return fmt.Errorf("find new leader: %w", err)
 			}
 			defer cli.Close()
+			break
 		}
 	}
 
@@ -667,7 +663,7 @@ func (a *App) makeRolesChanges(nodes []client.NodeInfo) RolesChanges {
 		// sem.Acquire will not block forever because the goroutines
 		// that release the semaphore will eventually timeout.
 		if err := sem.Acquire(context.Background(), 1); err != nil {
-			a.warn("Failed to acquire semaphore: %v", err)
+			a.warn("failed to acquire semaphore: %v", err)
 			wg.Done()
 			continue
 		}
