@@ -120,8 +120,6 @@ func WithVoters(n int) Option {
 // All App instances in a cluster must be created with the same WithStandBys
 // setting.
 //
-// The given value must be an odd number.
-//
 // The default value is 3.
 func WithStandBys(n int) Option {
 	return func(options *options) {
@@ -258,7 +256,7 @@ func defaultAddress() (addr string, err error) {
 		}
 	}
 
-	return "", fmt.Errorf("No suitable net.Interface found: %v", err)
+	return "", fmt.Errorf("no suitable net.Interface found: %v", err)
 }
 
 func defaultLogFunc(l client.LogLevel, format string, a ...interface{}) {
