@@ -376,7 +376,7 @@ func (c *Conn) Prepare(query string) (driver.Stmt, error) {
 // ExecContext is an optional interface that may be implemented by a Conn.
 func (c *Conn) ExecContext(ctx context.Context, query string, args []driver.NamedValue) (driver.Result, error) {
 	if len(args) > MaxTupleParams {
-		return nil, driverError(c.log, fmt.Errorf("too many parameters (%d) max = %d.", len(args), MaxTupleParams))
+		return nil, driverError(c.log, fmt.Errorf("too many parameters (%d) max = %d", len(args), MaxTupleParams))
 	}
 
 	protocol.EncodeExecSQL(&c.request, uint64(c.id), query, args)
@@ -405,7 +405,7 @@ func (c *Conn) Query(query string, args []driver.Value) (driver.Rows, error) {
 // QueryContext is an optional interface that may be implemented by a Conn.
 func (c *Conn) QueryContext(ctx context.Context, query string, args []driver.NamedValue) (driver.Rows, error) {
 	if len(args) > MaxTupleParams {
-		return nil, driverError(c.log, fmt.Errorf("too many parameters (%d) max = %d.", len(args), MaxTupleParams))
+		return nil, driverError(c.log, fmt.Errorf("too many parameters (%d) max = %d", len(args), MaxTupleParams))
 	}
 
 	protocol.EncodeQuerySQL(&c.request, uint64(c.id), query, args)
@@ -558,7 +558,7 @@ func (s *Stmt) NumInput() int {
 // ExecContext must honor the context timeout and return when it is canceled.
 func (s *Stmt) ExecContext(ctx context.Context, args []driver.NamedValue) (driver.Result, error) {
 	if len(args) > MaxTupleParams {
-		return nil, driverError(s.log, fmt.Errorf("too many parameters (%d) max = %d.", len(args), MaxTupleParams))
+		return nil, driverError(s.log, fmt.Errorf("too many parameters (%d) max = %d", len(args), MaxTupleParams))
 	}
 
 	protocol.EncodeExec(s.request, s.db, s.id, args)
@@ -590,7 +590,7 @@ func (s *Stmt) Exec(args []driver.Value) (driver.Result, error) {
 // QueryContext must honor the context timeout and return when it is canceled.
 func (s *Stmt) QueryContext(ctx context.Context, args []driver.NamedValue) (driver.Rows, error) {
 	if len(args) > MaxTupleParams {
-		return nil, driverError(s.log, fmt.Errorf("too many parameters (%d) max = %d.", len(args), MaxTupleParams))
+		return nil, driverError(s.log, fmt.Errorf("too many parameters (%d) max = %d", len(args), MaxTupleParams))
 	}
 
 	protocol.EncodeQuery(s.request, s.db, s.id, args)
